OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Tasks" : "Завдання",
    "Personal" : "Особисте",
    "{actor} created calendar {calendar}" : "{actor} створив(-ла) календар {calendar}",
    "You created calendar {calendar}" : "Ви створили календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} вилучив календар {calendar}",
    "You deleted calendar {calendar}" : "Ви вилучили календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} оновив(-ла) календар {calendar}",
    "You updated calendar {calendar}" : "Ви оновили календар {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} відновив календар {calendar}",
    "You restored calendar {calendar}" : "Ви відновили календар {calendar}",
    "You shared calendar {calendar} as public link" : "Ви поширили календар {calendar} як публічне посилання",
    "You removed public link for calendar {calendar}" : "Ви вилучили публічне посилання на календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} поширив календар {calendar} з вами",
    "You shared calendar {calendar} with {user}" : "Ви поширили календар {calendar} з {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} поширив календар {calendar} з {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} припинив поширення календаря {calendar} з вами",
    "You unshared calendar {calendar} from {user}" : "Ви припинили поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} припинив поширення календаря {calendar} з {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} припинив поширення календаря {calendar} між собою",
    "You shared calendar {calendar} with group {group}" : "Ви поширили календар {calendar} з групою {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} поширив календар {calendar} з групою {group}",
    "You unshared calendar {calendar} from group {group}" : "Ви припинили поширення календаря {calendar} з групою {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} припинив поширення календаря {calendar} з групою {group}",
    "Untitled event" : "Подія без назви",
    "{actor} created event {event} in calendar {calendar}" : "{actor} створив(-ла) подію {event} у календарі {calendar}",
    "You created event {event} in calendar {calendar}" : "Ви створили подію {event} у календарі {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} вилучив подію {event} з календаря {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Ви вилучили подію {event} з календаря {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} оновив(-ла) подію {event} у календарі {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ви оновили подію {event} у календарі {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} перемістив подію {event} з календаря {sourceCalendar} до календаря {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Ви перемістили подію {event} з календаря {sourceCalendar} до календаря {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} відновив подію {event} календаря {calendar}",
    "You restored event {event} of calendar {calendar}" : "Ви відновили подію {event} календаря {calendar}",
    "Busy" : "Зайнято",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} створив(-ла) завдання {todo} у списку {calendar}",
    "You created to-do {todo} in list {calendar}" : "Ви створили завдання {todo} у списку {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} вилучив(-ла) справу {todo} зі списку {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Ви вилучили завдання {todo} зі списку {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} оновив(-ла) завдання {todo} у списку {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Ви оновили завдання {todo} у списку {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} виконав(-ла) завдання {todo} зі списку {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Ви виконали завдання {todo} зі списку {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} знову відкрив(-ла) завдання у списку {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Ви знову відкрили завдання {todo} зі списку {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} перемістив(-ла) завдання {todo} зі списку {sourceCalendar} до списку {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Ви перемістили завдання {todo} зі списку {sourceCalendar} до списку {targetCalendar}",
    "Calendar, contacts and tasks" : "Календар, контакти та завдання",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> було змінено",
    "A calendar <strong>event</strong> was modified" : "Календарну <strong>подію</strong> було змінено",
    "A calendar <strong>to-do</strong> was modified" : "<strong>Завдання</strong> в календарі змінено",
    "Contact birthdays" : "Дні народження контактів",
    "Death of %s" : "Смерть %s",
    "Untitled calendar" : "Календар без назви",
    "Calendar:" : "Календар:",
    "Date:" : "Дата:",
    "Where:" : "Місце:",
    "Description:" : "Опис:",
    "_%n year_::_%n years_" : ["%n рік","%n років","%n років","%n роки "],
    "_%n month_::_%n months_" : ["%n місяць","%n місяців","%n місяців","%n місяці"],
    "_%n day_::_%n days_" : ["%n день","%n днів","%n днів","%n дні"],
    "_%n hour_::_%n hours_" : ["%n година","%n години","%n годин","%n години"],
    "_%n minute_::_%n minutes_" : ["%n хвилина","%n хвилин","%n хвилин","%n хвилини"],
    "%s (in %s)" : "%s (у %s)",
    "%s (%s ago)" : "%s (%s тому)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Місце: %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "Could not generate when statement" : "Не вдалося створити оператор \"коли\"",
    "Every Day for the entire day" : "Щодня впродовж усього дня",
    "Every Day for the entire day until %1$s" : "Щодня впродовж усього дня до %1$s",
    "Every Day between %1$s - %2$s" : "Щодня між %1$s - %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Щодня між %1$s- %2$sдо %3$s ",
    "Every %1$d Days for the entire day" : "Що %1$d днів впродовж усього дня",
    "Every %1$d Days for the entire day until %2$s" : "Що %1$d днів впродовж усього дня до %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Що %1$dднів між %2$s - %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Що %1$d днів між %2$s - %3$s до %4$s",
    "Could not generate event recurrence statement" : "Не вдалося створити оператор повторення події",
    "Every Week on %1$s for the entire day" : "Щотижня в %1$s впродовж усього дня",
    "Every Week on %1$s for the entire day until %2$s" : "Щотижня в %1$s впродовж усього дня до %2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Щотижня в %1$s між %2$s - %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Щотижня в %1$s між %2$s - %3$s до %4$s ",
    "Every %1$d Weeks on %2$s for the entire day" : "Що %1$d тижні в %2$s впродовж усього дня ",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Що %1$dтижні в %2$s впродовж усього дня до %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Що %1$d тижні в %2$s між %3$s - %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Що %1$d тижні в %2$s між %3$s - %4$s до %5$s",
    "Every Month on the %1$s for the entire day" : "Щомісяця %1$s впродовж усього дня ",
    "Every Month on the %1$s for the entire day until %2$s" : "Щомісяця %1$s  впродовж усього дня до %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Щомісяця %1$s між %2$s - %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Щомісяця %1$s між %2$s - %3$s до %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Що %1$d місяці %2$s впродовж усього дня",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Що %1$d місяці %2$s  впродовж усього дня до %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Що %1$d місяці %2$s між %3$s - %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Що %1$dмісяці %2$s між %3$s - %4$s до %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Щороку в %1$s, %2$s, впродовж усього дня",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Щороку в %1$s, %2$s, впродовж усього дня до %3$s ",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Щороку в %1$s, %2$s, між %3$s - %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Щороку в %1$s, %2$s, між %3$s - %4$s до %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Що %1$d роки в %2$s, %3$s, впродовж усього дня",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Що %1$d роки в %2$s, %3$s, впродовж усього дня до %4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Що %1$d роки в %2$s, %3$s, між %4$s - %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Що %1$d роки в %2$s, %3$s, між %4$s - %5$s до %6$s",
    "On specific dates for the entire day until %1$s" : "У визначені дати впродовж усього дня до %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "У визначені дати між %1$s - %2$s до %3$s",
    "Could not generate next recurrence statement" : "Не вдалося створити оператор наступного повторення",
    "Cancelled: %1$s" : "Скасовано: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" скасовано",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s прийняв ваше запрошення",
    "%1$s has tentatively accepted your invitation" : "%1$s попередньо прийняв ваше запрошення",
    "%1$s has declined your invitation" : "%1$s відмовився від вашого запрошення",
    "%1$s has responded to your invitation" : "%1$sвідповів(-ла) на ваше запрошення",
    "Invitation updated: %1$s" : "Запрошення оновлено: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s оновив(-ла) подію \"%2$s\"",
    "Invitation: %1$s" : "Запрошення: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s запрошує вас до \"%2$s\"",
    "Organizer:" : "Організатор:",
    "Attendees:" : "Учасники:",
    "Title:" : "Назва:",
    "When:" : "Коли:",
    "Location:" : "Місцевість:",
    "Link:" : "Посилання:",
    "Occurring:" : "Відбувається:",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "More options …" : "Більше варіантів …",
    "More options at %s" : "Більше варіантів на %s",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sunday" : "Неділя",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "First" : "Перший",
    "Second" : "Другий",
    "Third" : "Третій",
    "Fourth" : "Четвертий",
    "Last" : "Останній",
    "Second Last" : "Другий(-а) останній(-я)",
    "Third Last" : "Третій(-я) останній(-я)",
    "Fourth Last" : "Четвертий(-а) останній(-я)",
    "Contacts" : "Контакти",
    "{actor} created address book {addressbook}" : "{actor} створив(-ла) адресну книгу {addressbook}",
    "You created address book {addressbook}" : "Ви створили адресну книгу {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} вилучив(-ла) адресну книгу {addressbook}",
    "You deleted address book {addressbook}" : "Ви вилучили адресну книгу {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} оновив(-ла) адресну книгу {addressbook}",
    "You updated address book {addressbook}" : "Ви оновили адресну книгу {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} поділив(-ла-)ся з вами адресною книгою {addressbook}",
    "You shared address book {addressbook} with {user}" : "Ви надали доступ до адресної книги {addressbook} користувачу {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} поділив(-ла-)ся адресною книгою {addressbook} з {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} не надіслана адресна книга {addressbook} від вас",
    "You unshared address book {addressbook} from {user}" : "Ви скасували спільний доступ до адресної книги {addressbook} від користувача {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} не має спільного доступу до адресної книги {addressbook} від {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} забрав доступ до адресної книги {addressbook} від себе",
    "You shared address book {addressbook} with group {group}" : "Ви надали спільний доступ до адресної книги {addressbook} групі {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} поділив(-ла-)ся адресною книгою {addressbook} із групою {group}",
    "You unshared address book {addressbook} from group {group}" : "Ви скасували спільний доступ до адресної книги {addressbook} із групи {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} не має спільного доступу до адресної книги {addressbook} із групи {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} створив(-ла) контакт {card} в адресній книзі {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Ви створили контакт {card} в адресній книзі {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} вилучив(-ла) контакт {card} з адресної книги {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Ви вилучили контакт {card} з адресної книги {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} оновив(-ла) контакт {card} в адресній книзі {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ви оновили контакт {card} в адресній книзі {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Контактну</strong> або <strong>адресну книгу</strong> було змінено",
    "Accounts" : "Облікові записи",
    "System address book which holds all accounts" : "Системна адресна книга, в якій містяться всі облікові записи",
    "File is not updatable: %1$s" : "Файл не оновлюється: %1$s",
    "Failed to get storage for file" : "Не вдалося отримати дані про сховище для файлу",
    "Could not write to final file, canceled by hook" : "Не вдалося записати в остаточний файл, скасовано перехопленням",
    "Could not write file contents" : "Не вдалося записати вміст файлу",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байтів","%n байтів","%n байтів"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Помилка під час копіювання файлу в цільове розташування (скопійовано: %1$s, очікуваний розмір файлу: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Очікуваний розмір файлу %1$s, але читання (з клієнта Nextcloud) і запис (до сховища Nextcloud) %2$s. Це може бути проблема мережі на стороні надсилання або проблема запису в сховище на стороні сервера.",
    "Could not rename part file to final file, canceled by hook" : "Не вдалося перейменувати файл частини на остаточний файл, скасовано підхопленням",
    "Could not rename part file to final file" : "Не вдалося перейменувати файл частини на остаточний файл",
    "Failed to check file size: %1$s" : "Не вдалося перевірити розмір файлу: %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Неможливо відкрити файл: %1$s, хоча файл скоріше за все присутній",
    "Could not open file: %1$s, file doesn't seem to exist" : "Неможливо відкрити файл: %1$s, скоріше за все файл відсутній",
    "Encryption not ready: %1$s" : "Шифрування не готове: %1$s",
    "Failed to open file: %1$s" : "Не вдалося відкрити файл: %1$s",
    "Failed to unlink: %1$s" : "Не вдалося від’єднати: %1$s",
    "Failed to write file contents: %1$s" : "Не вдалося записати вміст файлу: %1$s",
    "File not found: %1$s" : "Файл не знайдено: %1$s",
    "Invalid target path" : "Недійсний шлях призначення",
    "System is in maintenance mode." : "Система в режимі обслуговування.",
    "Upgrade needed" : "Потрібне оновлення",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ваш %s мусить бути налаштований на використання HTTPS для надання доступу до CalDAV і CardDAV з iOS/macOS.",
    "Configures a CalDAV account" : "Налаштовує обліковий запис CalDAV",
    "Configures a CardDAV account" : "Налаштовує обліковий запис CardDAV",
    "Events" : "Події",
    "Untitled task" : "Завдання без назви",
    "Completed on %s" : "Завершено %s",
    "Due on %s by %s" : "До %s з боку %s",
    "Due on %s" : "До %s",
    "DAV system address book" : "Системна адресна книга DAV",
    "No outstanding DAV system address book sync." : "Немає незавершеної синхронізації системної адресної книги DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Синхронізація системної адресної книги DAV ще не запускалася, оскільки, або ваша система вже має понад 1000 користувачів, або сталася помилка. Будь ласка, запустіть синхронізацію вручну за допомогою команди \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "Точка доступу WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Неможливо перевірити, чи на вашому вебсервері правильно налаштовано доступ для синхронізації файлів через протокол WebDAV. Перевірте це вручну.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ваш вебсервер не налаштований як треба для синхронізації файлів, схоже інтерфейс WebDAV поламаний.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "На вашому вебсерверві правильно налаштовано доступ для синхронізації файлів через протокол WevDAV.",
    "Migrated calendar (%1$s)" : "Перенесений календар (%1$s)",
    "Calendars including events, details and attendees" : "Календарі, включно з подіями, деталями та відвідувачами",
    "Contacts and groups" : "Контакти та групи",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Відсутність збережено",
    "Failed to save your absence settings" : "Не вдалося зберегти налаштуванння про відсутність",
    "Absence cleared" : "Відсутність вилучено",
    "Failed to clear your absence settings" : "Не вдалося скинути ваші налаштування про відсутність",
    "First day" : "Перший день",
    "Last day (inclusive)" : "Останній день (включно)",
    "Out of office replacement (optional)" : "Заміна під час відсутності (необов'язково)",
    "Name of the replacement" : "Ім'я того, хто вас замінятиме",
    "No results." : "Відсутні результати.",
    "Start typing." : "Почніть вводити.",
    "Short absence status" : "Короткий статус відсутности",
    "Long absence Message" : "Довге повідомлення про відсутність",
    "Save" : "Зберегти",
    "Disable absence" : "Вимкнути відсутність",
    "Failed to load availability" : "Не вдалося завантажити доступність",
    "Saved availability" : "Збережена наявність",
    "Failed to save availability" : "Не вдалося зберегти наявність",
    "Time zone:" : "Часовий пояс:",
    "to" : "до",
    "Delete slot" : "Вилучити діапазон",
    "No working hours set" : "Робочий час не встановлено",
    "Add slot" : "Додати діапазон",
    "Weekdays" : "Дні тижня",
    "Pick a start time for {dayName}" : "Виберіть час початку для {dayName}",
    "Pick a end time for {dayName}" : "Виберіть час завершення для {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматично встановлювати статус користувача у \"Не турбувати\", коли ви не доступні. В цей проміжок часу ви не отримуватимете сповіщення.",
    "Availability" : "Доступність",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Будь ласка, налаштуйте ваші робочі години, щоб інші користувачі могли бачити, коли ви відсутні під час створення зустрічей.",
    "Absence" : "Відсутність",
    "Configure your next absence period." : "Налаштувати проміжки вашої відсутности",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Встановіть {calendarappstoreopen}застосунок Календар{linkclose}, {calendardocopen}з'єднайте ваш ноутбук та смартфон для синхронізації вашого календаря ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Будь-ласка переконайтеся у коректності налаштувань {emailopen}поштового сервера{linkclose}.",
    "Calendar server" : "Календар",
    "Send invitations to attendees" : "Надсилати запрошення учасникам",
    "Automatically generate a birthday calendar" : "Автоматично створити календар днів народження",
    "Birthday calendars will be generated by a background job." : "Календар днів народження буде згенеровано у фоновому завданні.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Отже вони не будуть доступні одразу після увімкнення, але з'являться згодом.",
    "Send notifications for events" : "Надсилати сповіщення про події",
    "Notifications are sent via background jobs, so these must occur often enough." : "Сповіщення надсилаються у фонових завданнях, тож вони мають запускатися достатньо часто.",
    "Send reminder notifications to calendar sharees as well" : "Також надсилайте нагадування користувачам вашого спільного календаря",
    "Reminders are always sent to organizers and attendees." : "Нагадування завжди надсилаються організаторам і учасникам.",
    "Enable notifications for events via push" : "Увімкнути push-сповіщення для подій",
    "There was an error updating your attendance status." : "Виникла помилка при оновленні вашого статусу учасника.",
    "Please contact the organizer directly." : "Будь-ласка повідомте організатора.",
    "Are you accepting the invitation?" : "Чи приймаєте ви запрошення?",
    "Tentative" : "Попередній",
    "Your attendance was updated successfully." : "Ваша участь успішно оновлена.",
    "Time:" : "Час:",
    "Could not open file" : "Не вдалося відкрити файл",
    "Invalid chunk name" : "Недійсна назва блоку",
    "Could not rename part file assembled from chunks" : "Не вдалося перейменувати файл частини, зібраний із фрагментів"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
